Crate ruff_cache

Crate ruff_cache 

Modules

filetime
globset

Structs

CacheKeyHasher

Constants

CACHE_DIR_NAME

Traits

CacheKey
A type that be used as part of a cache key.

Functions

cache_dir
Return the cache directory for a given project root.