Crate ruff_cache
ruff_
cache
0.0.2
All Items
Crate Items
Modules
Structs
Constants
Traits
Functions
Crate
ruff_
cache
Modules

filetime
globset
Structs

Cache
KeyHasher
Constants

CACHE_
DIR_
NAME
Traits

Cache
Key
A type that be used as part of a cache key.
Functions

cache_
dir
Return the cache directory for a given project root.